@@ -32,6 +32,14 @@ class MintDesktop:
         settings = Gio.Settings.new(schema)
         return settings.get_string(key)
 
+    def set_int(self, schema, key, value):
+        settings = Gio.Settings.new(schema)
+        settings.set_int(key, value)
+
+    def get_int(self, schema, key):
+        settings = Gio.Settings.new(schema)
+        return settings.get_int(key)
+
     def set_bool(self, schema, key, value):
         settings = Gio.Settings.new(schema)
         settings.set_boolean(key, value.get_active())
@@ -66,6 +74,24 @@ class MintDesktop:
         value = widget.get_model()[act]
         self.set_string(schema, key, value[1])
 
+    def init_combobox_int(self, schema, key, name):
+        source = Gio.SettingsSchemaSource.get_default()
+        if source.lookup(schema, True) != None:
+            widget = self.builder.get_object(name)
+            conf = self.get_int(schema, key)
+            index = 0
+            for row in widget.get_model():
+                if(conf == row[1]):
+                    widget.set_active(index)
+                    break
+                index = index + 1
+            widget.connect("changed", lambda x: self.combo_fallback_int(schema, key, x))
+
+    def combo_fallback_int(self, schema, key, widget):
+        act = widget.get_active()
+        value = widget.get_model()[act]
+        self.set_int(schema, key, value[1])
+
     # Change pages
     def side_view_nav(self, param):
         treePaths = param.get_selected_items()
@@ -125,24 +151,17 @@ class MintDesktop:
         side_desktop_options = SidePage(0, _("Desktop"), "user-desktop")
         side_windows = SidePage(1, _("Windows"), "preferences-system-windows")
         side_interface = SidePage(2, _("Interface"), "preferences-desktop")
-        side_terminal = SidePage(3, _("Terminal"), "terminal")
 
         self.compiz_path = os.path.expanduser('~/.config/compiz-1')
 
         wm_info = subprocess.getoutput("wmctrl -m")
         self.show_hide_options(wm_info.lower())
 
-        self.xfce = False
-        try:
-            if "xfce4" in os.environ['XDG_DATA_DIRS']:
-                self.xfce = True
-        except:
-            pass
-
-        if self.xfce:
-            self.sidePages = [side_windows, side_terminal]
+        if os.getenv("XDG_CURRENT_DESKTOP") == "XFCE":
+            self.sidePages = [side_windows]
+            self.builder.get_object("frame3").hide()
         else:
-            self.sidePages = [side_desktop_options, side_windows, side_interface, side_terminal]
+            self.sidePages = [side_desktop_options, side_windows, side_interface]
 
         # create the backing store for the side nav-view.
         theme = Gtk.IconTheme.get_default()
@@ -173,9 +192,7 @@ class MintDesktop:
         self.builder.get_object("compiz_settings_button").set_label(_("Configure Compiz"))
         self.builder.get_object("compiz_reset_button").set_label(_("Reset Compiz settings"))
         self.builder.get_object("label_icons").set_markup("<b>" + _("Icons") + "</b>")
-        self.builder.get_object("label_context_menus").set_markup("<b>" + _("Context menus") + "</b>")
         self.builder.get_object("label_toolbars").set_markup("<b>" + _("Toolbars") + "</b>")
-        self.builder.get_object("label_terminal").set_markup("<b>" + _("Terminal") + "</b>")
         self.builder.get_object("label_wm").set_markup("<b>" + _("Window Manager") + "</b>")
 
         self.builder.get_object("caption_desktop_icons").set_markup("<small><i><span foreground=\"#555555\">" + _("Select the items you want to see on the desktop:") + "</span></i></small>")
@@ -193,12 +210,8 @@ class MintDesktop:
         self.builder.get_object("checkbutton_titlebar_metacity").set_label(_("Use system font in titlebar"))
         self.builder.get_object("label_layouts_metacity").set_text(_("Buttons layout:"))
 
-        self.builder.get_object("checkbox_fortunes").set_label(_("Show fortune cookies"))
-
         self.builder.get_object("checkbutton_menuicon").set_label(_("Show icons on menus"))
         self.builder.get_object("checkbutton_button_icons").set_label(_("Show icons on buttons"))
-        self.builder.get_object("checkbutton_im_menu").set_label(_("Show Input Methods menu in context menus"))
-        self.builder.get_object("checkbutton_unicode").set_label(_("Show Unicode Control Character menu in context menus"))
 
         self.builder.get_object("label_tool_icons").set_text(_("Buttons labels:"))
         self.builder.get_object("label_icon_size").set_text(_("Icon size:"))
@@ -228,7 +241,7 @@ class MintDesktop:
 
         # Window Manager page
         layouts = Gtk.ListStore(str, str)
-        layouts.append([_("Traditional style (Right)"), "menu:minimize,maximize,close"])
+        layouts.append([_("Traditional style (Right)"), ":minimize,maximize,close"])
         layouts.append([_("Mac style (Left)"), "close,minimize,maximize:"])
 
         self.init_checkbox("org.mate.Marco.general", "reduced-resources", "checkbutton_resources_marco")
@@ -243,8 +256,6 @@ class MintDesktop:
 
         # interface page
         self.init_checkbox("org.mate.interface", "menus-have-icons", "checkbutton_menuicon")
-        self.init_checkbox("org.mate.interface", "show-input-method-menu", "checkbutton_im_menu")
-        self.init_checkbox("org.mate.interface", "show-unicode-menu", "checkbutton_unicode")
         self.init_checkbox("org.mate.interface", "buttons-have-icons", "checkbutton_button_icons")
         iconSizes = Gtk.ListStore(str, str)
         iconSizes.append([_("Small"), "small-toolbar"])
@@ -252,18 +263,13 @@ class MintDesktop:
         self.builder.get_object("combobox_icon_size").set_model(iconSizes)
         self.init_combobox("org.mate.interface", "toolbar-icons-size", "combobox_icon_size")
 
-        # terminal page
-        self.init_checkbox("com.linuxmint.terminal", "show-fortunes", "checkbox_fortunes")
-
         if "XDG_CURRENT_DESKTOP" in os.environ:
             current_desktop = os.environ["XDG_CURRENT_DESKTOP"]
             if current_desktop == "MATE":
                 wm_key = "mate-window-manager"
             else:
                 wm_key = "xfce-window-manager"
-            print(wm_key)
             settings = Gio.Settings("com.linuxmint.desktop")
-            wm = settings.get_string(wm_key)
             wms = Gtk.ListStore(str, str)
             compton = os.path.exists("/usr/bin/compton")
             if os.path.exists("/usr/bin/marco"):
@@ -296,6 +302,19 @@ class MintDesktop:
             self.init_combobox("com.linuxmint.desktop", wm_key, "combo_wm")
             self.builder.get_object("combo_wm").connect("changed", self.wm_changed)
 
+            # HiDPI
+            if current_desktop == "MATE":
+                options = Gtk.ListStore(str, int)
+                options.append([_("Auto"), 0])
+                options.append([_("Normal"), 1])
+                options.append([_("Double (HiDPI)"), 2])
+                self.builder.get_object("combo_hidpi").set_model(options)
+                self.init_combobox_int("org.mate.interface", "window-scaling-factor", "combo_hidpi")
+                self.builder.get_object("label_hidpi").set_text(_("User interface scaling"))
+            else:
+                self.builder.get_object("combo_hidpi").hide()
+                self.builder.get_object("label_hidpi").hide()
+
         # toolbar icon styles
         iconStyles = Gtk.ListStore(str, str)
         iconStyles.append([_("Text below items"), "both"])
